#!/usr/bin/env python3

"""

"""

from pathlib import Path
import click
from flask import Flask, request, session, current_app
import tomllib

from tentacles.blueprints import ui, api
from tentacles.store import Store


@click.group()
def cli():
    pass


def open_db():
    current_app.db = Store(current_app.config.get("db", {}).get("uri"))
    current_app.db.connect()


def commit_db(resp):
    current_app.db.commit()
    return resp


def user_session():
    if (session_id := request.cookies.get("sid", "")) and (
        uid := current_app.db.try_key(session_id)
    ):
        request.sid = session_id
        request.uid = uid
        _, gid, name, _ = current_app.db.fetch_user(uid)
        request.gid = gid
        request.username = name
        request.is_admin = gid == 0
    else:
        request.sid = None
        request.uid = None
        request.gid = None
        request.username = None
        request.is_admin = False


@cli.command()
@click.option("--hostname", "hostname", type=str, default="0.0.0.0")
@click.option("--port", "port", type=int, default=8080)
@click.option("--config", type=Path)
def serve(hostname: str, port: int, config: Path):
    app = Flask(__name__)
    if config:
        with open(config, "rb") as fp:
            app.config.update(tomllib.load(fp))

    print(app.config)

    app.before_first_request(open_db)
    app.before_request(user_session)
    app.after_request(commit_db)

    app.register_blueprint(ui.BLUEPRINT)
    app.register_blueprint(api.BLUEPRINT)

    app.run(host=hostname, port=port)


if __name__ == "__main__":
    cli()
