#!/usr/bin/env python3

"""Blueprints for HTML serving 'ui'."""

from datetime import timedelta
from importlib.resources import files

from flask import (
    Blueprint,
    current_app,
    request,
    Request,
    redirect,
    render_template,
    session,
    url_for,
    flash,
)

BLUEPRINT = Blueprint("ui", __name__)


def is_logged_in(authorization):
    return False


@BLUEPRINT.route("/")
def root():
    return (
        render_template(
            "index.html.j2",
            request=request,
        ),
        200,
    )


@BLUEPRINT.route("/login", methods=["GET", "POST"])
def login():
    if is_logged_in(request.authorization):
        return redirect("/")

    elif request.method == "POST":
        if sid := current_app.db.try_login(
            username := request.form["username"],
            request.form["password"],
            timedelta(days=1),
        ):
            resp = redirect("/")
            resp.set_cookie("sid", sid)
            flash(f"Welcome, {username}", category="success")
            return resp

        else:
            flash("Incorrect username/password", category="error")
            return render_template("login.html.j2")

    else:
        return render_template("login.html.j2")


@BLUEPRINT.route("/register", methods=["GET", "POST"])
def register():
    if is_logged_in(request.authorization):
        return redirect("/")
    elif request.method == "POST":
        try:
            if uid := current_app.db.try_create_user(
                request.form["username"], request.form["password"]
            ):
                flash(
                    "Please check your email for a verification request",
                    category="success",
                )
                return render_template("register.html.j2")
        except:
            pass

        flash("Unable to register that username", category="error")
        return render_template("register.html.j2")

    else:
        return render_template("register.html.j2")


@BLUEPRINT.route("/logout")
def logout():
    # Invalidate the user's authorization
    current_app.db.delete_key(request.sid)
    resp = redirect("/")
    resp.set_cookie("sid", "")
    return resp
